Skip to contents

Returns a data frame describing the nowcasting methods implemented in the package.

Usage

nc_available()

Value

A data frame with columns method, description, and available.

Examples

nc_available()
#>   method                                    description available
#> 1 bridge Bridge equation via OLS with optional AR terms      TRUE