R/compute.R
nc_available.Rd
Returns a data frame describing the nowcasting methods implemented in the package.
nc_available()
A data frame with columns method, description, and available.
method
description
available
nc_available() #> method description available #> 1 bridge Bridge equation via OLS with optional AR terms TRUE